@@ -61,6 +61,8 @@ typedef gboolean      (*ProcessFunction)        (YelpTocPager      *pager);
 
 typedef struct _YelpListing YelpListing;
 
+#define YELP_TOC_PAGER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), YELP_TYPE_TOC_PAGER, YelpTocPagerPriv))
+
 struct _YelpTocPagerPriv {
     gboolean      sk_docomf;
     GSList       *omf_pending;
@@ -191,6 +193,8 @@ toc_pager_class_init (YelpTocPagerClass *klass)
     pager_class->cancel       = toc_pager_cancel;
     pager_class->resolve_frag = toc_pager_resolve_frag;
     pager_class->get_sections = toc_pager_get_sections;
+
+    g_type_class_add_private (klass, sizeof (YelpTocPagerPriv));
 }
 
 static void
@@ -198,8 +202,7 @@ toc_pager_init (YelpTocPager *pager)
 {
     YelpTocPagerPriv *priv;
 
-    priv = g_new0 (YelpTocPagerPriv, 1);
-    pager->priv = priv;
+    pager->priv = priv = YELP_TOC_PAGER_GET_PRIVATE (pager);
 
     priv->parser = xmlNewParserCtxt ();
 
@@ -704,10 +707,12 @@ process_mandir_pending (YelpTocPager *pager)
  done:
     g_free (dirname);
 
-    priv->manpaths_i++;
-    if (priv->manpaths[priv->manpaths_i] == NULL) {
-	priv->manpaths_i = 0;
-	priv->langs_i++;
+    if (priv->manpaths) {
+	priv->manpaths_i++;
+	if (priv->manpaths[priv->manpaths_i] == NULL) {
+	    priv->manpaths_i = 0;
+	    priv->langs_i++;
+	}
     }
     if (langs[priv->langs_i] == NULL) {
 	priv->langs_i = 0;
@@ -745,7 +750,7 @@ process_info_pending (YelpTocPager *pager)
 {
     return FALSE;
 }
-#endif // ENABLE_INFO
+#endif /* ENABLE_INFO */
 
 static gboolean
 process_read_menu (YelpTocPager *pager)
@@ -784,7 +789,7 @@ process_read_menu (YelpTocPager *pager)
 	if (!xmlStrcmp (id, "index")) {
 	    xmlNodePtr new = xmlNewChild (node, NULL, "toc", NULL);
 	    xmlNewNsProp (new, NULL, "id", "Man");
-	    xmlNewChild (new, NULL, "title", _("Man Pages"));
+	    xmlNewChild (new, NULL, "title", _("Manual Pages"));
 	}
 #endif
 
@@ -916,6 +921,7 @@ process_xslt (YelpTocPager *pager)
 				      priv->toc_doc,
 				      (const gchar **)params, NULL, NULL,
 				      priv->transformContext);
+    /* Don't do this */
     g_signal_emit_by_name (pager, "finish");
 
  done:
@@ -1147,7 +1153,8 @@ xml_trim_titles (xmlNodePtr node)
 		keep_pri = cur_pri;
 		keep = cur;
 	    } else {
-		xmlFree (cur_lang);
+		if (cur_lang)
+		    xmlFree (cur_lang);
 	    }
 	}
     }
